==> blackchocobo_1.9.910-0~201907232153~ubuntu18.10.1.tar.xz: recipe/ff7tk/widgets/ItemList.h <==
/****************************************************************************/
//    copyright 2012 - 2016 Chris Rizzitello <sithlord48@gmail.com>         //
//                                                                          //
//    This file is part of FF7tk                                            //
//                                                                          //
//    FF7tk is free software: you can redistribute it and/or modify         //
//    it under the terms of the GNU General Public License as published by  //
//    the Free Software Foundation, either version 3 of the License, or     //
//    (at your option) any later version.                                   //
//                                                                          //
//    FF7tk is distributed in the hope that it will be useful,              //
//    but WITHOUT ANY WARRANTY; without even the implied warranty of        //
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          //
//    GNU General Public License for more details.                          //
/****************************************************************************/
#ifndef ITEMLIST_H
#define ITEMLIST_H

#include <QtWidgets>
#include "ItemPreview.h"
#include "ItemSelector.h"
#include "../data/FF7Item.h"

class ItemList : public QTableWidget
{
    Q_OBJECT
public:
    explicit ItemList(qreal Scale = 1, QWidget *parent = 0);
protected:
    bool eventFilter(QObject *, QEvent *);
    void changeEvent(QEvent *e);
signals:
    void itemsChanged(QList<quint16> items);
public slots:
    void setItems(QList<quint16> items);
    void setMaximumItemQty(int maxQty);
    void setEditableItemCombo(bool);
private slots:
    void listSelectionChanged(int row, int colum, int prevRow, int prevColum);
    void itemSelector_changed(quint16);
private:
    void itemupdate();
    void updateItem(int row);
    FF7Item Items;
    int itemQtyLimit;
    ItemSelector *itemSelector;
    ItemPreview *itemPreview;
    QList<quint16> itemlist;
    bool createdSelector;
    bool createdTooltip;
    bool editableItemCombo;
    qreal scale;
};
#endif // ITEMLIST_H

==> blackchocobo_1.10.0-0~202008041320~ubuntu18.04.1.tar.xz: recipe/ff7tk/widgets/ItemList.h <==
/****************************************************************************/
//    copyright 2012 - 2020 Chris Rizzitello <sithlord48@gmail.com>         //
//                                                                          //
//    This file is part of FF7tk                                            //
//                                                                          //
//    FF7tk is free software: you can redistribute it and/or modify         //
//    it under the terms of the GNU General Public License as published by  //
//    the Free Software Foundation, either version 3 of the License, or     //
//    (at your option) any later version.                                   //
//                                                                          //
//    FF7tk is distributed in the hope that it will be useful,              //
//    but WITHOUT ANY WARRANTY; without even the implied warranty of        //
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
//    GNU General Public License for more details.                          //
/****************************************************************************/
#pragma once

#include <QTableWidget>
#include <QEvent>

class ItemPreview;
class ItemSelector;

class ItemList : public QTableWidget
{
    Q_OBJECT
public:
    explicit ItemList(qreal Scale = 1, QWidget *parent = nullptr);
protected:
    bool eventFilter(QObject *, QEvent *);
    void changeEvent(QEvent *e);
signals:
    void itemsChanged(QList<quint16> items);
public slots:
    void setItems(QList<quint16> items);
    void setMaximumItemQty(int maxQty);
    void setEditableItemCombo(bool);
private slots:
    void listSelectionChanged(int row, int colum, int prevRow, int prevColum);
    void itemSelector_changed(quint16);
private:
    void itemupdate();
    void updateItem(int row);
    ItemSelector *itemSelector = nullptr;
    ItemPreview *itemPreview = nullptr;
    QList<quint16> itemlist;
    qreal scale;
    int itemQtyLimit;
    bool createdSelector;
    bool createdTooltip;
    bool editableItemCombo;
};
